@@ -4,7 +4,7 @@ from QTKit import *
 
 class TestQTCaptureDecompressedVideoOutput (TestCase):
     def testInformalProtocols(self):
-        self.assertIsInstance(protocols.QTCaptureDecompressedVideoOutputDelegate, objc.informal_protocol)
+        self.assertIsInstance(protocols.QTCaptureDecompressedVideoOutput_Delegate, objc.informal_protocol)
 
 if __name__ == "__main__":
     main()
